compute_layout

Function compute_layout 

pub fn compute_layout(fields: &[FieldDesc]) -> (Vec<usize>, usize)
Computes std430-compatible byte offsets for fields, in order, and the total size of the packed struct, rounded up to a 16-byte multiple as std430 requires for a struct used as an SSBO array element.